lomltk is a package that provides useful python utility functions for Machine Learning researchers/engineers

## Getting Started
### Requirements
*See [requirements.txt](requirements.txt) and [env.yaml](env.yaml) for detail*

- Python 3.7+

### Install dependencies
```shell
# using pip
pip install -r requirements.txt

# or using conda
conda env create -f env.yaml
```